@@ -21,7 +21,7 @@ import threading
 import time
 from typing import IO, Any, Optional, TextIO
 
-__version__ = "0.10.1"
+__version__ = "0.11.0"
 __schema_version__ = "0.2.0"
 
 
@@ -747,8 +747,9 @@ class Arguments:
         )
         parser.add_argument(
             "-l",
-            "--log_level",
+            "--log-level",
             default=DEFAULT_LOG_LEVEL,
+            type=str.upper,
             choices=("NONE", "CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG"),
             help="Level of log output to stderr, use NONE to entirely disable.",
         )
