@@ -1,4 +1,5 @@
 import argparse
+import logging
 import os
 import sys
 from typing import List, Optional
@@ -6,8 +7,17 @@ from con_duct.suite.ls import LS_FIELD_CHOICES, ls
 from con_duct.suite.plot import matplotlib_plot
 from con_duct.suite.pprint_json import pprint_json
 
+lgr = logging.getLogger("con-duct")
+DEFAULT_LOG_LEVEL = os.environ.get("DUCT_LOG_LEVEL", "INFO").upper()
+
 
 def execute(args: argparse.Namespace) -> int:
+
+    if args.log_level == "NONE":
+        logging.disable(logging.CRITICAL)
+    else:
+        logging.basicConfig(level=args.log_level)
+
     result = args.func(args)
     if not isinstance(result, int):
         raise TypeError(
@@ -22,6 +32,14 @@ def main(argv: Optional[List[str]] = None) -> None:
         description="A suite of commands to manage or manipulate con-duct logs.",
         usage="con-duct <command> [options]",
     )
+    parser.add_argument(
+        "-l",
+        "--log-level",
+        default=DEFAULT_LOG_LEVEL,
+        choices=("NONE", "CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG"),
+        type=str.upper,
+        help="Level of log output to stderr, use NONE to entirely disable.",
+    )
     subparsers = parser.add_subparsers(dest="command", help="Available subcommands")
 
     # Subcommand: pp
@@ -66,7 +84,7 @@ def main(argv: Optional[List[str]] = None) -> None:
         nargs="+",
         metavar="FIELD",
         help=f"List of fields to show. Prefix is always included implicitly as the first field. "
-        f"Available choices: {', '.join(LS_FIELD_CHOICES)}.",
+        f"Available choices: {', '.join(sorted(LS_FIELD_CHOICES))}.",
         choices=LS_FIELD_CHOICES,
         default=[
             "command",
@@ -87,6 +105,15 @@ def main(argv: Optional[List[str]] = None) -> None:
         help="Path to duct report files, only `info.json` would be considered. "
         "If not provided, the program will glob for files that match DUCT_OUTPUT_PREFIX.",
     )
+    parser_ls.add_argument(
+        "-e",
+        "--eval-filter",
+        help="Python expression to filter results based on available fields. "
+        "The expression is evaluated for each entry, and only those that return True are included. "
+        "See --fields for all supported fields. "
+        "Example: --eval-filter \"filter_this=='yes'\" filters entries where 'filter_this' is 'yes'. "
+        "You can use 're' for regex operations (e.g., --eval-filter \"re.search('2025.02.09.*', prefix)\").",
+    )
     parser_ls.set_defaults(func=ls)
 
     args = parser.parse_args(argv)
